@@ -127,8 +127,20 @@ API Reference
 #  |  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 #  |  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #
-#  Builds on top of https://github.com/Chilipp/autodocsumm
-#  GPLv2 Licensed
+#  Builds on top of, and PatchedAutoDocSummDirective based on, https://github.com/Chilipp/autodocsumm
+#  | Copyright 2016-2019, Philipp S. Sommer
+#  | Copyright 2020-2021, Helmholtz-Zentrum Hereon
+#  |
+#  | Licensed under the Apache License, Version 2.0 (the "License");
+#  | you may not use this file except in compliance with the License.
+#  | You may obtain a copy of the License at
+#  |
+#  |     http://www.apache.org/licenses/LICENSE-2.0
+#  |
+#  | Unless required by applicable law or agreed to in writing,
+#  | software distributed under the License is distributed on an "AS IS" BASIS,
+#  | WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+#  | See the License for the specific language governing permissions and limitations under the License.
 #
 
 # stdlib
@@ -139,6 +151,7 @@ from typing import Any, List, Optional, Tuple, Type
 
 # 3rd party
 import autodocsumm  # type: ignore
+import sphinx
 from docutils import nodes
 from domdf_python_tools.stringlist import StringList
 from sphinx import addnodes
@@ -153,10 +166,10 @@ from sphinx.ext.autodoc import (
 		logger,
 		special_member_re
 		)
+from sphinx.ext.autodoc.directive import DocumenterBridge, process_documenter_options
 from sphinx.ext.autodoc.importer import get_module_members
 from sphinx.ext.autosummary import Autosummary, FakeDirective
 from sphinx.locale import __
-from sphinx.util.docstrings import extract_metadata
 from sphinx.util.inspect import getdoc, safe_getattr
 
 # this package
@@ -164,6 +177,13 @@ from sphinx_toolbox._data_documenter import DataDocumenter
 from sphinx_toolbox.more_autodoc import ObjectMembers
 from sphinx_toolbox.utils import SphinxExtMetadata, allow_subclass_add, get_first_matching, metadata_add_version
 
+if sphinx.version_info > (4, 1):
+	# 3rd party
+	from sphinx.util.docstrings import separate_metadata
+else:
+	# 3rd party
+	from sphinx.util.docstrings import extract_metadata
+
 __all__ = [
 		"PatchedAutosummary",
 		"PatchedAutoSummModuleDocumenter",
@@ -395,7 +415,7 @@ class PatchedAutoSummModuleDocumenter(autodocsumm.AutoSummModuleDocumenter):
 		# process members and determine which to skip
 		for (membername, member) in members:
 			# if isattr is True, the member is documented as an attribute
-			if member is INSTANCEATTR:
+			if member is INSTANCEATTR or (namespace, membername) in attr_docs:
 				isattr = True
 			else:
 				isattr = False
@@ -418,9 +438,14 @@ class PatchedAutoSummModuleDocumenter(autodocsumm.AutoSummModuleDocumenter):
 				cls_doc = self.get_attr(cls, "__doc__", None)
 				if cls_doc == doc:
 					doc = None
+
+			if sphinx.version_info > (4, 1):
+				doc, metadata = separate_metadata(doc)  # type: ignore
+			else:
+				metadata = extract_metadata(doc)  # type: ignore
+
 			has_doc = bool(doc)
 
-			metadata = extract_metadata(doc)  # type: ignore
 			if "private" in metadata:
 				# consider a member private if docstring has "private" metadata
 				isprivate = True
@@ -481,20 +506,18 @@ class PatchedAutoSummModuleDocumenter(autodocsumm.AutoSummModuleDocumenter):
 				# let extensions preprocess docstrings
 				try:
 					skip_user = self.env.app.emit_firstresult(
-							"autodoc-skip-member", self.objtype, membername, member, not keep, self.options
+							"autodoc-skip-member",
+							self.objtype,
+							membername,
+							member,
+							not keep,
+							self.options,
 							)
 					if skip_user is not None:
 						keep = not skip_user
 				except Exception as exc:
-					logger.warning(
-							__(
-									'autodoc: failed to determine %r to be documented, '
-									'the following exception was raised:\n%s'
-									),
-							member,
-							exc,
-							type="autodoc"
-							)
+					msg = 'autodoc: failed to determine %r to be documented, the following exception was raised:\n%s'
+					logger.warning(__(msg), member, exc, type="autodoc")
 					keep = False
 
 			if keep:
@@ -502,7 +525,7 @@ class PatchedAutoSummModuleDocumenter(autodocsumm.AutoSummModuleDocumenter):
 
 		return ret
 
-	def get_object_members(self, want_all: bool) -> Tuple[bool, List[Tuple[str, Any]]]:
+	def get_object_members(self, want_all: bool) -> Tuple[bool, ObjectMembers]:
 		"""
 		Return a tuple of  ``(members_check_module, members)``,
 		where ``members`` is a list of ``(membername, member)`` pairs of the members of ``self.object``.
@@ -554,6 +577,55 @@ class PatchedAutoSummClassDocumenter(autodocsumm.AutoSummClassDocumenter):
 			self.add_autosummary()
 
 
+class PatchedAutoDocSummDirective(autodocsumm.AutoDocSummDirective):
+	"""
+	Patched ``AutoDocSummDirective`` which uses :py:obj:`None` for the members option rather than an empty string.
+
+	.. attention:: This class is not part of the public API.
+	"""
+
+	def run(self):
+		reporter = self.state.document.reporter
+
+		if hasattr(reporter, "get_source_and_line"):
+			source, lineno = reporter.get_source_and_line(self.lineno)
+		else:
+			source, lineno = (None, None)
+
+		# look up target Documenter
+		objtype = self.name[4:-4]  # strip prefix (auto-) and suffix (-summ).
+		doccls = self.env.app.registry.documenters[objtype]
+
+		self.options["autosummary-force-inline"] = "True"
+		self.options["autosummary"] = "True"
+		if "no-members" not in self.options:
+			self.options["members"] = None
+
+		# process the options with the selected documenter's option_spec
+		try:
+			documenter_options = process_documenter_options(doccls, self.config, self.options)
+		except (KeyError, ValueError, TypeError) as exc:
+			# an option is either unknown or has a wrong type
+			logger.error(
+					"An option to %s is either unknown or has an invalid value: %s",
+					self.name,
+					exc,
+					location=(self.env.docname, lineno),
+					)
+			return []
+
+		# generate the output
+		params = DocumenterBridge(self.env, reporter, documenter_options, lineno, self.state)
+		documenter = doccls(params, self.arguments[0])
+		documenter.add_autosummary()
+
+		node = nodes.paragraph()
+		node.document = self.state.document
+		self.state.nested_parse(params.result, 0, node)
+
+		return node.children
+
+
 @metadata_add_version
 def setup(app: Sphinx) -> SphinxExtMetadata:
 	"""
@@ -566,6 +638,9 @@ def setup(app: Sphinx) -> SphinxExtMetadata:
 	app.setup_extension("autodocsumm")
 
 	app.add_directive("autosummary", PatchedAutosummary, override=True)
+	app.add_directive("autoclasssumm", PatchedAutoDocSummDirective, override=True)
+	app.add_directive("automodulesumm", PatchedAutoDocSummDirective, override=True)
+
 	autodocsumm.AutosummaryDocumenter.add_autosummary = add_autosummary
 	allow_subclass_add(app, PatchedAutoSummModuleDocumenter)
 	allow_subclass_add(app, PatchedAutoSummClassDocumenter)
