@@ -32,6 +32,7 @@ General utility functions.
 #
 
 # stdlib
+import atexit
 import functools
 import re
 from typing import Any, Callable, Dict, Iterable, List, Mapping, Optional, Pattern, Set, Tuple, Type, TypeVar, cast
@@ -87,6 +88,8 @@ OptionSpec = Mapping[str, Callable[[str], Any]]
 
 _T = TypeVar("_T")
 
+atexit.register(GITHUB_COM.session.close)
+
 
 @functools.lru_cache()
 def make_github_url(username: str, repository: str) -> RequestsURL:
@@ -367,7 +370,7 @@ Type annotation for Sphinx extensions' ``setup`` functions.
 @deprecated(
 		deprecated_in="2.16.0",
 		removed_in="3.0.0",
-		current_version="2.16.1",
+		current_version="2.17.0",
 		details="Users of this function should reimplement it in their own code.",
 		)
 def begin_generate(
